@@ -129,6 +129,7 @@ def rep_bench(func, n, initfunc=None, MAXREPS=10, MAXTIME=60.0, profile=False, p
     tls.sort()
     worst = tls[-1]
     best = tls[0]
+    _assert(best > worstemptymeasure*MARGINOFERROR, "%s(n=%s) took %0.10f seconds, but we cannot measure times much less than about %0.10f seconds. Try a more time-consuming variant (such as higher n)." % (func, n, best, worstemptymeasure*MARGINOFERROR,))
     m = len(tls)/4
     if m > 0:
         mthbest = tls[m-1]
@@ -187,7 +188,6 @@ def bench_it(func, n, profile=False, profresults="pyutil-benchutil.prof"):
     empty = emstop - emsta
     if empty > worstemptymeasure:
         worstemptymeasure = empty
-    _assert(timeelapsed*MARGINOFERROR > worstemptymeasure, "Invoking func %s(%s) took only %0.20f seconds, but we cannot accurately measure times much less than %0.20f seconds.  Therefore we cannot produce good results here.  Try benchmarking a more time-consuming variant." % (func, n, timeelapsed, worstemptymeasure,))
     return timeelapsed
 
 def bench(func, initfunc=None, TOPXP=21, MAXREPS=5, MAXTIME=60.0, profile=False, profresults="pyutil-benchutil.prof", outputjson=False, jsonresultsfname="pyutil-benchutil-results.json", UNITS_PER_SECOND=1):
